@@ -37,5 +37,5 @@ class ProblemResult:
         self.points: float = dic["points"]
         self.penalty: int = dic["penalty"]
         self.rejected_attempt_count: int = dic["rejectedAttemptCount"]
-        self.type: ProblemResultType = ProblemResultType(dic["type"])  # Enum: PRELIMINARY, FINAL
+        self.type: ProblemResultType = ProblemResultType[dic["type"]]  # Enum: PRELIMINARY, FINAL
         self.best_submission_time_seconds: int = dic["bestSubmissionTimeSeconds"]
